OiRA

# OiRA@Daimler

Online Interactive Risk Assessment

## My risk assessments

Filters

Close

Hide archived risk assessments

Select an earlier risk assessment to complete or review or start a new session.

- #### Private Security, Grafton Street

  Started 5 May 2019

  More

- #### Commercial guarding, Montgomery Building

  Started 6 March 2020

  More

## Available OiRA tools

Back

## index-logged-in.html

More…

- New risk assessment
- Show archived risk assessments
- All types of risk assessments Only regular risk assessments Only contractor risk assessments

Help

Standard search Advanced search

- Loading Risk Assessments…